package com.sparkrift.test;

import java.util.Iterator;
import java.util.Random;
import java.util.Vector;

import com.badlogic.gdx.ApplicationListener;
import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.GL10;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureAtlas;

public class LibGDXSpriteBatch implements ApplicationListener {
	private SpriteBatch batch;
	
	final int NUM_SPRITES = 33000;
	Vector<SpriteInfo> sprites = new Vector<SpriteInfo>();
	Random rand = new Random();
	BitmapFont font;
	
	@Override
	public void create() {
		// create a sprite batch
        batch = new SpriteBatch();        

        // load texture from packed file
        com.badlogic.gdx.graphics.g2d.Sprite sprite = new TextureAtlas(Gdx.files.internal("data/pack")).createSprite("blowfish");
        font = new BitmapFont();
        
        // initialize the sprites
        for(int i = 0; i < NUM_SPRITES; i++)
        {
        	sprites.add(new SpriteInfo(sprite, 1920, 1080));
        }
	}

	@Override
	public void dispose() {
		batch.dispose();
	}
	
	private void update(float dt) {
		Iterator<SpriteInfo> it = sprites.iterator();
		while(it.hasNext())
        {
			SpriteInfo s = it.next();
			s.update(dt);
        }        
	}

	@Override
	public void render() {
		// update the game logic
		update(Gdx.graphics.getDeltaTime());
		
		// clear the screen
        Gdx.gl.glClear(GL10.GL_COLOR_BUFFER_BIT);
        
        // iterate through all of our sprites to draw them
        Iterator<SpriteInfo> it = sprites.iterator();
        
        // start the batch draw
        batch.begin();
        while(it.hasNext())
        {
        	SpriteInfo s = it.next();
        	// draw a sprite
        	batch.draw(s.texture(), s.x(), s.y(), s.originX(), s.originY(), s.width(), s.height(), s.scale(), s.scale(), s.rotation(), 0, 0, (int)s.width(), (int)s.height(), false, false);
        }
        font.draw(batch, "FPS: " + String.valueOf(Gdx.graphics.getFramesPerSecond()), 100, 100);
        // end the batch draw
        batch.end();
	}

	@Override
	public void resize(int width, int height) {
	}

	@Override
	public void pause() {
	}

	@Override
	public void resume() {
	}
}
