package com.sparkrift.test;

import java.util.Random;

import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.math.Vector2;

public class SpriteInfo {
	
	final float MAX_SCALE = 2;
	
	private float scale;
	private float scaleSpeed;
	private float rotation;
	private float rotationSpeed;
	private float speed;
	private Vector2 location;
	private Vector2 direction;
	private Random rand;
	private int viewWidth;
	private int viewHeight;
	private Sprite sprite;
	private Vector2 origin;
	
	public SpriteInfo(Sprite sprite, int width, int height) {
		this.sprite = sprite;
		this.viewWidth = width;
		this.viewHeight = height;
		this.rand = new Random();
		
		this.origin = new Vector2(sprite.getWidth() / (float)2, sprite.getHeight() / (float)2);
		// Start at the normal scale
		this.scale = 1;
		// Random rotation
		this.rotation = rand.nextInt(360);
        // Random rotation speed
		this.rotationSpeed = rand.nextInt(360) - 180;
        // Random scaling speed
		this.scaleSpeed = rand.nextInt(8) - 4;
        // Random start location
		this.location = new Vector2((float)rand.nextInt(width), (float)rand.nextInt(height));
        // Random movement speed
		this.speed = rand.nextInt(450) + 50;
        // Random movement direction
		this.direction = new Vector2((float)(-1 + 2 * rand.nextDouble()), (float)(-1 + 2 * rand.nextDouble()));
	}
	
	public float x() {
		return location.x;
	}
	
	public float y() {
		return location.y;
	}
	
	public float originX() {
		return origin.x;
	}
	
	public float originY() {
		return origin.y;
	}
	
	public float width() {
		return sprite.getWidth();
	}
	
	public float height() {
		return sprite.getHeight();
	}
	
	public float scale() {
		return scale;
	}
	
	public float rotation() {
		return rotation;
	}
	
	public Texture texture() {
		return sprite.getTexture();
	}
	
	public void update(float dt) {
        // Set rotation
		rotation += rotationSpeed * dt;
		
		// Determine if we're going to scale past the cap
        float scaleAmount = scaleSpeed * dt;
        if (scale + scaleAmount <= -MAX_SCALE || scale + scaleAmount >= MAX_SCALE)
        {
            // Reverse scale
            scaleAmount = -scaleAmount;
            scaleSpeed = -scaleSpeed;
        }
        // Set scale
        scale += scaleAmount;
        if ( scale < -MAX_SCALE )
        {
        	scale = -MAX_SCALE;
        }
        else if ( scale > MAX_SCALE )
        {
        	scale = MAX_SCALE;
        }
        
        // Determine if we're going to move past a view boundary
        Vector2 moveAmount = new Vector2(direction).mul(speed).mul(dt);
        Vector2 newLocation = new Vector2(location).add(moveAmount);
        if (newLocation.x < 0 || newLocation.x > viewWidth || newLocation.y < 0 || newLocation.y > viewHeight)
        {
            // Reverse movement
            moveAmount = moveAmount.mul(-1);
            newLocation = new Vector2(location).add(moveAmount);
            direction = direction.mul(-1);
        }
        // Set location
        location = newLocation;
	}
}
